Module util

Module util 

Enums

ExecType

Traits

GetFirstOrLast
GetNextOrPrev
RevIf
Warn
WarnWithDetails

Functions

analyse_exec
collect_desktop_files
Collects all .desktop files from standard directories according to the XDG Base Directory Specification.
collect_mime_files
Collects all mimeapps.list files from standard directories according to the XDG Base Directory Specification.
command_exists
Convenience wrapper that returns true if the command exists somewhere.
daemon_running
find_command
Try to find an executable named name.
get_boot_id
get_daemon_socket_path_buff