Enums
Traits
Functions
- analyse_
exec - collect_
desktop_ files - Collects all .desktop files from standard directories according to the XDG Base Directory Specification.
- collect_
mime_ files - Collects all mimeapps.list files from standard directories according to the XDG Base Directory Specification.
- command_
exists - Convenience wrapper that returns true if the command exists somewhere.
- daemon_
running - find_
command - Try to find an executable named
name. - get_
boot_ id - get_
daemon_ socket_ path_ buff